class e32BitCipher:
    def __init__(self, key: int = 0x1AC32B4D):
        self.key = key & 0xFFFFFFFF

    def encrypt(self, s: str) -> str:
        data = s.encode('utf-8')
        result = 0
        for i, b in enumerate(data):
            key_byte = (self.key >> (8 * (i % 4))) & 0xFF
            result ^= (b ^ key_byte) << (8 * (i % 4))
        return f"{result:08x}"

    def decrypt(self, hex_str: str) -> str:
        value = int(hex_str, 16)
        bytes_out = []
        for i in range(4):
            key_byte = (self.key >> (8 * i)) & 0xFF
            b = ((value >> (8 * i)) & 0xFF) ^ key_byte
            if b == 0:
                break
            bytes_out.append(b)
        return bytes(bytes_out).decode('utf-8')


from setuptools import setup

setup(
    name="cp32",
    version="1.0.0",    
    py_modules=["cp32"], 
    author="wew1234GD",
    author_email="candyfoxowo28@gmail.com",
    description="simple cipher",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url="https://github.com/wew1234GD/32BitCipher",
    license="MIT",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
